# The AIDDL Core Library

This is the Python implementation of the AIDDL Core Library.

It provides everything needed for 

- Parsing AIDDL files
- Working with containers and modules
- Creating terms and types
- Evaluating terms and types
- Default functions for evaluation

